"use client";

// src/use-echarts.ts
import { init, use as echartsUse } from "echarts/core";
import { useEffect, useRef, useState } from "react";

// src/events.ts
var echartsEvents = {
  onClick: "click",
  onDoubleClick: "dblclick",
  onMouseDown: "mousedown",
  onMouseMove: "mousemove",
  onMouseOver: "mouseover",
  onMouseOut: "mouseout",
  onGlobalOut: "globalout",
  onContextMenu: "contextmenu",
  onHighlight: "highlight",
  onDownplay: "downplay",
  onSelectChanged: "selectchanged",
  onLegendSelectChanged: "legendselectchanged",
  onLegendSelected: "legendselected",
  onLegendUnselected: "legendunselected",
  onLegendInverseSelect: "legendinverseselect",
  onLegendScroll: "legendscroll",
  onDataZoom: "datazoom",
  onDataRangeSelected: "datarangeselected",
  onTimelineChanged: "timelinechanged",
  onTimelinePlayChanged: "timelineplaychanged",
  onRestore: "restore",
  onDataViewChanged: "dataviewchanged",
  onMagicTypeChanged: "magictypechanged",
  onGeoSelectChanged: "geoselectchanged",
  onGeoSelected: "geoselected",
  onGeoUnselected: "geounselected",
  onAxisAreaSelected: "axisareaselected",
  onBrush: "brush",
  onBrushEnd: "brushend",
  onBrushSelected: "brushselected",
  onGlobalCursorTaken: "globalcursortaken",
  onRendered: "rendered",
  onFinished: "finished"
};

// src/use-echarts.ts
var useECharts = ({
  // Init
  devicePixelRatio,
  height,
  locale,
  pointerSize,
  renderer,
  theme,
  use,
  useCoarsePointer,
  useDirtyRect,
  width,
  // eChartsInstance
  group,
  // SetOption
  lazyUpdate,
  notMerge,
  replaceMerge,
  silent,
  transition,
  darkMode,
  media,
  options,
  stateAnimation,
  // Option
  angleAxis,
  animation,
  animationDelay,
  animationDelayUpdate,
  animationDuration,
  animationDurationUpdate,
  animationEasing,
  animationEasingUpdate,
  animationThreshold,
  aria,
  axisPointer,
  backgroundColor,
  blendMode,
  brush,
  calendar,
  color,
  dataZoom,
  dataset,
  geo,
  graphic,
  grid,
  hoverLayerThreshold,
  legend,
  parallel,
  parallelAxis,
  polar,
  progressive,
  progressiveThreshold,
  radar,
  radiusAxis,
  series,
  singleAxis,
  textStyle,
  timeline,
  title,
  toolbox,
  tooltip,
  useUTC,
  visualMap,
  xAxis,
  yAxis,
  // Events
  onAxisAreaSelected,
  onBrush,
  onBrushEnd,
  onBrushSelected,
  onClick,
  onContextMenu,
  onDataRangeSelected,
  onDataViewChanged,
  onDataZoom,
  onDoubleClick,
  onDownplay,
  onFinished,
  onGeoSelectChanged,
  onGeoSelected,
  onGeoUnselected,
  onGlobalCursorTaken,
  onGlobalOut,
  onHighlight,
  onLegendInverseSelect,
  onLegendScroll,
  onLegendSelectChanged,
  onLegendSelected,
  onLegendUnselected,
  onMagicTypeChanged,
  onMouseDown,
  onMouseMove,
  onMouseOut,
  onMouseOver,
  onRendered,
  onRestore,
  onSelectChanged,
  onTimelineChanged,
  onTimelinePlayChanged
}) => {
  const containerRef = useRef();
  const echartsRef = useRef();
  const resizeObserverRef = useRef();
  const [started, setStarted] = useState(false);
  const echartsInstance = echartsRef.current;
  async function setContainerRef(node) {
    if (containerRef.current && echartsRef.current)
      return;
    containerRef.current = node;
    echartsRef.current = await startEcharts();
    resizeObserverRef.current = startResizeObserver();
    setStarted(true);
  }
  async function startEcharts() {
    if (!containerRef.current)
      return;
    const useOpts = use || await getGlobalUse();
    echartsUse(useOpts);
    return init(containerRef.current, theme, {
      devicePixelRatio,
      height,
      locale,
      pointerSize,
      renderer,
      useCoarsePointer,
      useDirtyRect,
      width
    });
  }
  function startResizeObserver() {
    const resizeObserver = new ResizeObserver(() => {
      echartsRef.current?.resize();
    });
    if (containerRef.current)
      resizeObserver.observe(containerRef.current);
    return resizeObserver;
  }
  useEffect(() => {
    if (!echartsInstance)
      return;
    if (group)
      echartsInstance.group = group;
  }, [group, started]);
  useEffect(() => {
    if (!echartsInstance)
      return;
    echartsInstance.clear();
    echartsInstance.setOption(
      {
        angleAxis,
        animation,
        animationDelay,
        animationDelayUpdate,
        animationDuration,
        animationDurationUpdate,
        animationEasing,
        animationEasingUpdate,
        animationThreshold,
        aria,
        axisPointer,
        backgroundColor,
        blendMode,
        brush,
        calendar,
        color,
        darkMode,
        dataset,
        dataZoom,
        geo,
        graphic,
        grid,
        hoverLayerThreshold,
        legend,
        media,
        options,
        parallel,
        parallelAxis,
        polar,
        progressive,
        progressiveThreshold,
        radar,
        radiusAxis,
        series,
        singleAxis,
        stateAnimation,
        textStyle,
        timeline,
        title,
        toolbox,
        tooltip,
        useUTC,
        visualMap,
        xAxis,
        yAxis
      },
      {
        lazyUpdate,
        notMerge,
        replaceMerge,
        silent,
        transition
      }
    );
  }, [
    angleAxis,
    animation,
    animationDelay,
    animationDelayUpdate,
    animationDuration,
    animationDurationUpdate,
    animationEasing,
    animationEasingUpdate,
    animationThreshold,
    aria,
    axisPointer,
    backgroundColor,
    blendMode,
    brush,
    calendar,
    color,
    darkMode,
    dataset,
    dataZoom,
    geo,
    graphic,
    grid,
    hoverLayerThreshold,
    legend,
    media,
    options,
    parallel,
    parallelAxis,
    polar,
    progressive,
    progressiveThreshold,
    radar,
    radiusAxis,
    series,
    singleAxis,
    stateAnimation,
    textStyle,
    timeline,
    title,
    toolbox,
    tooltip,
    useUTC,
    visualMap,
    xAxis,
    yAxis,
    //
    lazyUpdate,
    notMerge,
    replaceMerge,
    silent,
    transition,
    //
    started
  ]);
  useEffect(() => {
    if (!echartsInstance)
      return;
    if (onAxisAreaSelected) {
      echartsInstance.on(echartsEvents.onAxisAreaSelected, onAxisAreaSelected);
    }
    if (onBrush) {
      echartsInstance.on(echartsEvents.onBrush, onBrush);
    }
    if (onBrushEnd) {
      echartsInstance.on(echartsEvents.onBrushEnd, onBrushEnd);
    }
    if (onBrushSelected) {
      echartsInstance.on(echartsEvents.onBrushSelected, onBrushSelected);
    }
    if (onClick) {
      echartsInstance.on(echartsEvents.onClick, onClick);
    }
    if (onContextMenu) {
      echartsInstance.on(echartsEvents.onContextMenu, onContextMenu);
    }
    if (onDataRangeSelected) {
      echartsInstance.on(echartsEvents.onDataRangeSelected, onDataRangeSelected);
    }
    if (onDataViewChanged) {
      echartsInstance.on(echartsEvents.onDataViewChanged, onDataViewChanged);
    }
    if (onDataZoom) {
      echartsInstance.on(echartsEvents.onDataZoom, onDataZoom);
    }
    if (onDoubleClick) {
      echartsInstance.on(echartsEvents.onDoubleClick, onDoubleClick);
    }
    if (onDownplay) {
      echartsInstance.on(echartsEvents.onDownplay, onDownplay);
    }
    if (onFinished) {
      echartsInstance.on(echartsEvents.onFinished, onFinished);
    }
    if (onGeoSelectChanged) {
      echartsInstance.on(echartsEvents.onGeoSelectChanged, onGeoSelectChanged);
    }
    if (onGeoSelected) {
      echartsInstance.on(echartsEvents.onGeoSelected, onGeoSelected);
    }
    if (onGeoUnselected) {
      echartsInstance.on(echartsEvents.onGeoUnselected, onGeoUnselected);
    }
    if (onGlobalCursorTaken) {
      echartsInstance.on(echartsEvents.onGlobalCursorTaken, onGlobalCursorTaken);
    }
    if (onGlobalOut) {
      echartsInstance.on(echartsEvents.onGlobalOut, onGlobalOut);
    }
    if (onHighlight) {
      echartsInstance.on(echartsEvents.onHighlight, onHighlight);
    }
    if (onLegendInverseSelect) {
      echartsInstance.on(echartsEvents.onLegendInverseSelect, onLegendInverseSelect);
    }
    if (onLegendScroll) {
      echartsInstance.on(echartsEvents.onLegendScroll, onLegendScroll);
    }
    if (onLegendScroll) {
      echartsInstance.on(echartsEvents.onLegendScroll, onLegendScroll);
    }
    if (onLegendSelectChanged) {
      echartsInstance.on(echartsEvents.onLegendSelectChanged, onLegendSelectChanged);
    }
    if (onLegendSelected) {
      echartsInstance.on(echartsEvents.onLegendSelected, onLegendSelected);
    }
    if (onLegendUnselected) {
      echartsInstance.on(echartsEvents.onLegendUnselected, onLegendUnselected);
    }
    if (onMagicTypeChanged) {
      echartsInstance.on(echartsEvents.onMagicTypeChanged, onMagicTypeChanged);
    }
    if (onMouseDown) {
      echartsInstance.on(echartsEvents.onMouseDown, onMouseDown);
    }
    if (onMouseMove) {
      echartsInstance.on(echartsEvents.onMouseMove, onMouseMove);
    }
    if (onMouseOut) {
      echartsInstance.on(echartsEvents.onMouseOut, onMouseOut);
    }
    if (onMouseOver) {
      echartsInstance.on(echartsEvents.onMouseOver, onMouseOver);
    }
    if (onRendered) {
      echartsInstance.on(echartsEvents.onRendered, onRendered);
    }
    if (onRestore) {
      echartsInstance.on(echartsEvents.onRestore, onRestore);
    }
    if (onSelectChanged) {
      echartsInstance.on(echartsEvents.onSelectChanged, onSelectChanged);
    }
    if (onTimelineChanged) {
      echartsInstance.on(echartsEvents.onTimelineChanged, onTimelineChanged);
    }
    if (onTimelinePlayChanged) {
      echartsInstance.on(echartsEvents.onTimelinePlayChanged, onTimelinePlayChanged);
    }
  }, [
    onAxisAreaSelected,
    onBrush,
    onBrushEnd,
    onBrushSelected,
    onClick,
    onContextMenu,
    onDataRangeSelected,
    onDataViewChanged,
    onDataZoom,
    onDoubleClick,
    onDownplay,
    onFinished,
    onGeoSelectChanged,
    onGeoSelected,
    onGeoUnselected,
    onGlobalCursorTaken,
    onGlobalOut,
    onHighlight,
    onLegendInverseSelect,
    onLegendScroll,
    onLegendSelectChanged,
    onLegendSelected,
    onLegendUnselected,
    onMagicTypeChanged,
    onMouseDown,
    onMouseMove,
    onMouseOut,
    onMouseOver,
    onRendered,
    onRestore,
    onSelectChanged,
    onTimelineChanged,
    onTimelinePlayChanged,
    //
    started
  ]);
  return [setContainerRef, echartsRef.current];
};
async function getGlobalUse() {
  const all = [
    import("echarts/features"),
    import("echarts/charts"),
    import("echarts/components"),
    import("echarts/renderers")
  ];
  const promise = await Promise.all(all.map((m) => m.then((m2) => Object.values(m2))));
  return promise.flat();
}

// src/use-connect.ts
import { connect, disconnect } from "echarts/core";
import { useState as useState2 } from "react";
var useConnect = (group) => {
  const [isConnected, setIsConnected] = useState2(false);
  function onChange(connected) {
    if (connected) {
      connect(group);
    } else {
      disconnect(group);
    }
    setIsConnected(connected);
  }
  return [isConnected, onChange];
};

// src/echart.tsx
import { jsx } from "react/jsx-runtime";
var EChart = ({
  // Init
  devicePixelRatio,
  height,
  locale,
  pointerSize,
  renderer,
  theme,
  use,
  useCoarsePointer,
  useDirtyRect,
  width,
  // eChartsInstance
  group,
  // SetOption
  lazyUpdate,
  notMerge,
  replaceMerge,
  silent,
  transition,
  darkMode,
  media,
  options,
  stateAnimation,
  // Option
  angleAxis,
  animation,
  animationDelay,
  animationDelayUpdate,
  animationDuration,
  animationDurationUpdate,
  animationEasing,
  animationEasingUpdate,
  animationThreshold,
  aria,
  axisPointer,
  backgroundColor,
  blendMode,
  brush,
  calendar,
  color,
  dataZoom,
  dataset,
  geo,
  graphic,
  grid,
  hoverLayerThreshold,
  legend,
  parallel,
  parallelAxis,
  polar,
  progressive,
  progressiveThreshold,
  radar,
  radiusAxis,
  series,
  singleAxis,
  textStyle,
  timeline,
  title,
  toolbox,
  tooltip,
  useUTC,
  visualMap,
  xAxis,
  yAxis,
  // Events
  onAxisAreaSelected,
  onBrush,
  onBrushEnd,
  onBrushSelected,
  onClick,
  onContextMenu,
  onDataRangeSelected,
  onDataViewChanged,
  onDataZoom,
  onDoubleClick,
  onDownplay,
  onFinished,
  onGeoSelectChanged,
  onGeoSelected,
  onGeoUnselected,
  onGlobalCursorTaken,
  onGlobalOut,
  onHighlight,
  onLegendInverseSelect,
  onLegendScroll,
  onLegendSelectChanged,
  onLegendSelected,
  onLegendUnselected,
  onMagicTypeChanged,
  onMouseDown,
  onMouseMove,
  onMouseOut,
  onMouseOver,
  onRendered,
  onRestore,
  onSelectChanged,
  onTimelineChanged,
  onTimelinePlayChanged,
  ...rest
}) => {
  const [ref] = useECharts({
    // Init
    devicePixelRatio,
    height,
    locale,
    pointerSize,
    renderer,
    theme,
    use,
    useCoarsePointer,
    useDirtyRect,
    width,
    // eChartsInstance
    group,
    // SetOption
    lazyUpdate,
    notMerge,
    replaceMerge,
    silent,
    transition,
    darkMode,
    media,
    options,
    stateAnimation,
    // Option
    angleAxis,
    animation,
    animationDelay,
    animationDelayUpdate,
    animationDuration,
    animationDurationUpdate,
    animationEasing,
    animationEasingUpdate,
    animationThreshold,
    aria,
    axisPointer,
    backgroundColor,
    blendMode,
    brush,
    calendar,
    color,
    dataZoom,
    dataset,
    geo,
    graphic,
    grid,
    hoverLayerThreshold,
    legend,
    parallel,
    parallelAxis,
    polar,
    progressive,
    progressiveThreshold,
    radar,
    radiusAxis,
    series,
    singleAxis,
    textStyle,
    timeline,
    title,
    toolbox,
    tooltip,
    useUTC,
    visualMap,
    xAxis,
    yAxis,
    // Events
    onAxisAreaSelected,
    onBrush,
    onBrushEnd,
    onBrushSelected,
    onClick,
    onContextMenu,
    onDataRangeSelected,
    onDataViewChanged,
    onDataZoom,
    onDoubleClick,
    onDownplay,
    onFinished,
    onGeoSelectChanged,
    onGeoSelected,
    onGeoUnselected,
    onGlobalCursorTaken,
    onGlobalOut,
    onHighlight,
    onLegendInverseSelect,
    onLegendScroll,
    onLegendSelectChanged,
    onLegendSelected,
    onLegendUnselected,
    onMagicTypeChanged,
    onMouseDown,
    onMouseMove,
    onMouseOut,
    onMouseOver,
    onRendered,
    onRestore,
    onSelectChanged,
    onTimelineChanged,
    onTimelinePlayChanged
  });
  return /* @__PURE__ */ jsx("div", { ...rest, ref });
};
export {
  EChart,
  useConnect,
  useECharts
};
//# sourceMappingURL=index.mjs.map